@@ -1,12 +1,12 @@
 
 /*
  *  agUtils.c
- *  $Id: agUtils.c,v 1.22 2002/09/20 04:56:44 bkorb Exp $
+ *  $Id: agUtils.c,v 1.26 2003/02/15 22:58:59 bkorb Exp $
  *  This is the main routine for autogen.
  */
 
 /*
- *  AutoGen copyright 1992-2002 Bruce Korb
+ *  AutoGen copyright 1992-2003 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -78,6 +78,34 @@ strlcpy( char* dest, tCC* src, size_t n )
 #endif
 
 
+EXPORT char*
+aprf( const char* pzFmt, ... )
+{
+    char* pz;
+    va_list ap;
+    va_start( ap, pzFmt );
+    (void)vasprintf( &pz, pzFmt, ap );
+    va_end( ap );
+#ifdef MEMDEBUG
+    {
+        char* pzDup;
+        AGDUPSTR( pzDup, pz, "aprf" );
+        free( pz );
+        pz = pzDup;
+    }
+#endif
+    if (pz == NULL) {
+        tSCC zMsg[] = "could not allocate for or formatting failed on:\n";
+        char z[ 256 ];
+        strcpy( z, zMsg );
+        strncpy( z + sizeof( zMsg )-1, pzFmt, sizeof(z) - sizeof(zMsg));
+        z[ sizeof(z)-1 ] = NUL;
+        AG_ABEND( z );
+    }
+    return pz;
+}
+
+
 EXPORT void
 doOptions( int arg_ct, char** arg_vec )
 {
@@ -156,7 +184,7 @@ doOptions( int arg_ct, char** arg_vec )
          *  Otherwise, use the basename of the definitions file
          */
         OPT_ARG( BASE_NAME ) = \
-        pzD = AGALOC( strlen( pz )+1, "def file name" );
+        pzD = AGALOC( strlen( pz )+1, "derived base name" );
 
         while ((*pz != NUL) && (*pz != '.'))  *(pzD++) = *(pz++);
         *pzD = NUL;
@@ -258,9 +286,13 @@ addSysEnv( char* pzEnvName )
             break;
     }
     if (getenv( pzEnvName ) == NULL) {
+        char* pz;
+
         if (OPT_VALUE_TRACE > TRACE_NOTHING)
             fprintf( pfTrace, "Adding ``%s'' to environment\n", pzEnvName );
-        putenv( asprintf( zFmt, pzEnvName ));
+        pz = aprf( zFmt, pzEnvName );
+        TAGMEM( pz, "Added environment var" );
+        putenv( pz );
     }
 }
 
