@@ -1,12 +1,12 @@
 
 /*
  *  autogen.h
- *  $Id: autogen.h,v 1.31 2002/09/20 04:56:45 bkorb Exp $
+ *  $Id: autogen.h,v 1.35 2003/02/15 22:58:59 bkorb Exp $
  *  Global header file for AutoGen
  */
 
 /*
- *  AutoGen copyright 1992-2002 Bruce Korb
+ *  AutoGen copyright 1992-2003 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -126,8 +126,8 @@ struct macro_desc {
     int         endIndex;  /* End of block macro     */
     int         sibIndex;  /* Sibling macro (ELIF or SELECT) */
 
-    off_t       ozName;    /* macro name (sometimes) */
-    off_t       ozText;    /* associated text        */
+    uintptr_t   ozName;    /* macro name (sometimes) */
+    uintptr_t   ozText;    /* associated text        */
     long        res;       /* some sort of result    */
     void*       funcPrivate;
 };
@@ -254,11 +254,12 @@ MODE tFpStack*   pCurFp           VALUE( NULL );
 MODE tOutSpec*   pOutSpecList     VALUE( NULL );
 MODE jmp_buf     fileAbort        VALUE( { 0 } );
 MODE char*       pzCurStart       VALUE( NULL );
-MODE off_t       curStartOff      VALUE( 0 );
+MODE uintptr_t   curStartOff      VALUE( 0 );
 MODE tForInfo    forInfo          VALUE( { 0 } );
 MODE FILE*       pfTrace          VALUE( NULL );
 
 MODE tCC*        serverArgs[2]    VALUE( { NULL } );
+MODE tCC*        pzShellProgram   VALUE( NULL );
 
 /*
  *  AutoGen definiton and template context
@@ -324,6 +325,7 @@ MKSTRING( FileLine,  "\tfrom %s line %d\n" );
 MKSTRING( ShDone,    "ShElL-OuTpUt-HaS-bEeN-cOmPlEtEd" );
 MKSTRING( NotStr,    "ERROR: %s is not a string\n" );
 MKSTRING( DevNull,   "/dev/null" );
+MKSTRING( ShellEnv,  "SHELL" );
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
@@ -360,7 +362,7 @@ size_t strlcpy( char* dest, const char* src, size_t n );
 static inline char* ag_scm2zchars( SCM s, tCC* type )
 {
     if (! gh_string_p( s ))
-        AG_ABEND( asprintf( zNotStr, type ));
+        AG_ABEND( aprf( (char*)zNotStr, type ));
 
     if (SCM_SUBSTRP(s))
         s = scm_makfromstr( SCM_ROCHARS(s), SCM_ROLENGTH(s), 0 );
