@@ -1,12 +1,12 @@
 
 /*
  *  defDirect.c
- *  $Id: defDirect.c,v 1.21 2002/07/07 20:41:16 bkorb Exp $
+ *  $Id: defDirect.c,v 1.26 2003/02/15 22:58:59 bkorb Exp $
  *  This module processes definition file directives.
  */
 
 /*
- *  AutoGen copyright 1992-2002 Bruce Korb
+ *  AutoGen copyright 1992-2003 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -203,8 +203,8 @@ skipToEndif( char* pzScan )
         else {
             pz = strstr( pzScan, zCheckList );
             if (pz == NULL)
-                AG_ABEND( asprintf( zNoEndif, pCurCtx->pzFileName,
-                                    pCurCtx->lineNo ));
+                AG_ABEND( aprf( zNoEndif, pCurCtx->pzFileName,
+                                pCurCtx->lineNo ));
 
             pzScan = pz + STRSIZE( zCheckList );
         }
@@ -263,8 +263,8 @@ skipToElseEnd( char* pzScan )
         else {
             pz = strstr( pzScan, zCheckList );
             if (pz == NULL)
-                AG_ABEND( asprintf( zNoEndif, pCurCtx->pzFileName,
-                                    pCurCtx->lineNo ));
+                AG_ABEND( aprf( zNoEndif, pCurCtx->pzFileName,
+                                pCurCtx->lineNo ));
 
             pzScan = pz + STRSIZE( zCheckList );
         }
@@ -418,9 +418,10 @@ doDir_define( char* pzArg, char* pzScan )
 STATIC char*
 doDir_elif( char* pzArg, char* pzScan )
 {
-    AG_ABEND( asprintf( "`#elif' directive encountered out of context"
-                        "\tin %s on line %d\n",
-                        pCurCtx->pzFileName, pCurCtx->lineNo ));
+    tSCC z[] =
+        "`#elif' directive encountered out of context\n\tin %s on line %d\n";
+
+    AG_ABEND( aprf( z, pCurCtx->pzFileName, pCurCtx->lineNo ));
 }
 
 
@@ -435,8 +436,8 @@ STATIC char*
 doDir_else( char* pzArg, char* pzScan )
 {
     if (--ifdefLevel < 0)
-        AG_ABEND( asprintf( zNoMatch, pCurCtx->pzFileName,
-                            pCurCtx->lineNo, "else" ));
+        AG_ABEND( aprf( zNoMatch, pCurCtx->pzFileName, pCurCtx->lineNo,
+                        "else" ));
 
     return skipToEndif( pzScan );
 }
@@ -452,8 +453,8 @@ STATIC char*
 doDir_endif( char* pzArg, char* pzScan )
 {
     if (--ifdefLevel < 0)
-        AG_ABEND( asprintf( zNoMatch, pCurCtx->pzFileName,
-                            pCurCtx->lineNo, "endif" ));
+        AG_ABEND( aprf( zNoMatch, pCurCtx->pzFileName, pCurCtx->lineNo,
+                        "endif" ));
 
     return pzScan;
 }
@@ -471,8 +472,8 @@ doDir_endshell( char* pzArg, char* pzScan )
      *  In actual practice, the '#endshell's must be consumed inside
      *  the 'doDir_shell()' procedure.
      */
-    AG_ABEND( asprintf( zNoMatch, pCurCtx->pzFileName,
-                        pCurCtx->lineNo, "endshell" ));
+    AG_ABEND( aprf( zNoMatch, pCurCtx->pzFileName, pCurCtx->lineNo,
+                    "endshell" ));
 }
 
 
@@ -487,8 +488,8 @@ doDir_endshell( char* pzArg, char* pzScan )
 STATIC char*
 doDir_error( char* pzArg, char* pzScan )
 {
-    AG_ABEND( asprintf( "#error directive -- in %s on line %d\n\t%s\n",
-                        pCurCtx->pzFileName, pCurCtx->lineNo, pzArg ));
+    AG_ABEND( aprf( "#error directive -- in %s on line %d\n\t%s\n",
+                    pCurCtx->pzFileName, pCurCtx->lineNo, pzArg ));
 }
 
 
@@ -639,15 +640,15 @@ doDir_include( char* pzArg, char* pzScan )
         char*  pz = pzScan;
 
         if (fp == NULL)
-            AG_ABEND( asprintf( zCannot, errno, "open file", zFullName,
-                                strerror( errno )));
+            AG_ABEND( aprf( zCannot, errno, "open file", zFullName,
+                            strerror( errno )));
 
         do  {
             size_t rdct = fread( (void*)pz, 1, inclSize, fp );
 
             if (rdct == 0)
-                AG_ABEND( asprintf( zCannot, errno, "read file", zFullName,
-                                    strerror( errno )));
+                AG_ABEND( aprf( zCannot, errno, "read file", zFullName,
+                                strerror( errno )));
 
             pz += rdct;
             inclSize -= rdct;
@@ -699,7 +700,7 @@ doDir_line( char* pzArg, char* pzScan )
         *pz = NUL;
     }
     AGFREE( (void*)pCurCtx->pzFileName );
-    AGDUPSTR( pCurCtx->pzFileName, pzArg, "line directive file name" );
+    AGDUPSTR( pCurCtx->pzFileName, pzArg, "#line file name" );
 
     return pzScan;
 }
@@ -775,9 +776,8 @@ doDir_shell( char* pzArg, char* pzScan )
 
     pzScan = strstr( pzScan, zEndShell );
     if (pzScan == NULL)
-        AG_ABEND( asprintf( "Missing #endshell after '#shell' "
-                            "in %s on line %d\n", pCurCtx->pzFileName,
-                            pCurCtx->lineNo ));
+        AG_ABEND( aprf( "Missing #endshell after '#shell' in %s on line %d\n",
+                        pCurCtx->pzFileName, pCurCtx->lineNo ));
 
     *pzScan = NUL;
 
@@ -795,6 +795,9 @@ doDir_shell( char* pzArg, char* pzScan )
      */
     pCurCtx->pzScan  = pzScan;
 
+    if (pzShellProgram == NULL)
+        pzShellProgram = getDefine( zShellEnv );
+
     /*
      *  Run the shell command.  The output text becomes the
      *  "file text" that is used for more definitions.
@@ -821,7 +824,7 @@ doDir_shell( char* pzArg, char* pzScan )
     /*
      *  Set up the rest of the context structure
      */
-    AGDUPSTR( pCtx->pzFileName, zShellText, zShellText );
+    AGDUPSTR( pCtx->pzFileName, zShellText, "shell text" );
     pCtx->pzScan     =
     pCtx->pzData     = (char*)(pCtx+1);
     pCtx->lineNo     = 0;
