@@ -1,12 +1,12 @@
 /*
- *  $Id: defFind.c,v 1.18 2002/01/19 19:20:45 bkorb Exp $
+ *  $Id: defFind.c,v 1.22 2003/02/15 22:58:59 bkorb Exp $
  *  This module loads the definitions, calls yyparse to decipher them,
  *  and then makes a fixup pass to point all children definitions to
  *  their parent definition (except the fixed "rootEntry" entry).
  */
 
 /*
- *  AutoGen copyright 1992-2002 Bruce Korb
+ *  AutoGen copyright 1992-2003 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -41,14 +41,9 @@ tSC zDefinitionName[ MAXPATHLEN ];
 
 STATIC tDefEntry* findEntryByIndex( tDefEntry* pE, char* pzScan );
 
-
-STATIC void
-illFormedName( void )
-{
-    char* pz = asprintf( zNameRef, zDefinitionName,
-                         pCurTemplate->pzFileName, pCurMacro->lineNo );
-    AG_ABEND( pz );
-}
+#define ILLFORMEDNAME() \
+    AG_ABEND( aprf( zNameRef, zDefinitionName, \
+              pCurTemplate->pzFileName, pCurMacro->lineNo ));
 
 
 STATIC tDefEntry*
@@ -163,8 +158,7 @@ addResult( tDefEntry* pDE, tDefEntryList* pDEL )
     if (++(pDEL->usedCt) > pDEL->allocCt) {
         pDEL->allocCt += pDEL->allocCt + 8; /* 8, 24, 56, ... */
         pDEL->papDefEntry = (tDefEntry**)
-            AGREALOC( (void*)pDEL->papDefEntry,
-                      pDEL->allocCt * sizeof( void* ),
+            AGREALOC( (void*)pDEL->papDefEntry, pDEL->allocCt * sizeof( void* ),
                       "added find result" );
     }
 
@@ -477,7 +471,7 @@ defEntrySearch( char* pzName, tDefStack* pDefStack, ag_bool* pIsIndexed )
          */
         pcBrace = strchr( pcBrace, ']' );
         if (pcBrace == NULL)
-            illFormedName();
+            ILLFORMEDNAME();
 
         /*
          *  IF we are at the end of the definition,
@@ -491,7 +485,7 @@ defEntrySearch( char* pzName, tDefStack* pDefStack, ag_bool* pIsIndexed )
             break;
 
         default:
-            illFormedName();
+            ILLFORMEDNAME();
         }
         /* FALLTHROUGH */
 
@@ -505,7 +499,7 @@ defEntrySearch( char* pzName, tDefStack* pDefStack, ag_bool* pIsIndexed )
         break;
 
     default:
-        illFormedName();
+        ILLFORMEDNAME();
     }
 
     /*
@@ -605,7 +599,7 @@ entryListSearch( char* pzName, tDefStack* pDefStack )
              */
         not_found:
             if (defList.nestLevel != 0)
-                illFormedName();
+                ILLFORMEDNAME();
 
             /*
              *  Don't bother returning zero entry list.  Just return NULL.
@@ -669,7 +663,7 @@ entryListSearch( char* pzName, tDefStack* pDefStack )
          */
         pcBrace = strchr( pcBrace, ']' );
         if (pcBrace == NULL)
-            illFormedName();
+            ILLFORMEDNAME();
 
         /*
          *  IF we are at the end of the definition,
@@ -683,7 +677,7 @@ entryListSearch( char* pzName, tDefStack* pDefStack )
             break;
 
         default:
-            illFormedName();
+            ILLFORMEDNAME();
         }
         /* FALLTHROUGH */
 
@@ -697,7 +691,7 @@ entryListSearch( char* pzName, tDefStack* pDefStack )
         break;
 
     default:
-        illFormedName();
+        ILLFORMEDNAME();
     }
 
     /*
