@@ -1,12 +1,12 @@
 /*  -*- Mode: C -*-
  *
  *  expExtract.c
- *  $Id: expExtract.c,v 3.3 2002/03/29 04:11:19 bkorb Exp $
+ *  $Id: expExtract.c,v 1.10 2003/02/15 22:58:59 bkorb Exp $
  *  This module implements a file extraction function.
  */
 
 /*
- *  AutoGen copyright 1992-2002 Bruce Korb
+ *  AutoGen copyright 1992-2003 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -271,8 +271,8 @@ ag_scm_extract( SCM file, SCM marker, SCM caveat, SCM def )
         if (gh_string_p( caveat ) && (SCM_LENGTH( caveat ) > 0))
             pzCaveat = ag_scm2zchars( caveat, "extract caveat" );
 
-        pzStart = asprintf( pzMarker, "START", pzCaveat );
-        pzEnd   = asprintf( pzMarker, "END  ", pzCaveat );
+        pzStart = aprf( pzMarker, "START", pzCaveat );
+        pzEnd   = aprf( pzMarker, "END  ", pzCaveat );
     }
 
     {
