@@ -1,7 +1,7 @@
 /*
  *  Tables of Text Functions for AutoGen
  *
- *  copyright 1992-2002 Bruce Korb
+ *  copyright 1992-2003 Bruce Korb
  *
  *  AutoGen is free software.
  *  
@@ -216,6 +216,7 @@ tSCC zFn_Expr_4[]    = "(";
 tSCC zFn_Expr_5[]    = "`";
 tSCC zFn_Expr_6[]    = "\"";
 tSCC zFn_Expr_7[]    = "'";
+tSCC zFn_Expr_8[]    = ".";
 tSCC zFn_For[]       = "FOR";
 tSCC zFn_If[]        = "IF";
 tSCC zFn_Include[]   = "INCLUDE";
@@ -231,10 +232,10 @@ tSCC zFn_While[]     = "WHILE";
  *  Some have multiple names (e.g. selection clauses).
  */
 #define FUNC_ALIAS_LOW_INDEX    0
-#define FUNC_ALIAS_HIGH_INDEX   11
-#define FUNC_NAMES_LOW_INDEX    12
-#define FUNC_NAMES_HIGH_INDEX   25
-#define FUNCTION_NAME_CT        26
+#define FUNC_ALIAS_HIGH_INDEX   12
+#define FUNC_NAMES_LOW_INDEX    13
+#define FUNC_NAMES_HIGH_INDEX   26
+#define FUNCTION_NAME_CT        27
 
 /*
  *  And now, the table sorted by string content
@@ -247,6 +248,7 @@ tNameType nameTypeTable[ FUNCTION_NAME_CT ] = {
     {  1, zFn_Expr_4,      FTYP_EXPR },
     {  1, zFn_Select_2,    FTYP_SELECT },
     {  1, zFn_Expr_0,      FTYP_EXPR },
+    {  1, zFn_Expr_8,      FTYP_EXPR },
     {  1, zFn_Expr_3,      FTYP_EXPR },
     {  1, zFn_Select_1,    FTYP_SELECT },
     {  1, zFn_Expr_1,      FTYP_EXPR },
