@@ -1,12 +1,12 @@
 
 /*
  *  agTempl.c
- *  $Id: tpProcess.c,v 1.19 2002/04/14 22:30:29 bkorb Exp $
+ *  $Id: tpProcess.c,v 1.23 2003/02/15 22:58:59 bkorb Exp $
  *  Parse and process the template data descriptions
  */
 
 /*
- *  AutoGen copyright 1992-2002 Bruce Korb
+ *  AutoGen copyright 1992-2003 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -71,7 +71,7 @@ generateBlock( tTemplate*   pT,
                 fputs( "  ", pfTrace );
                 for (ct=0; ct < 32; ct++) {
                     char ch = *(pz++);
-                    if (ch == '\0')
+                    if (ch == NUL)
                         break;
                     if (ch == '\n')
                         break;
@@ -304,8 +304,8 @@ openOutFile( tOutSpec* pOutSpec, tFpStack* pStk )
          *  Now formulate the output file name in the buffer
          *  provided as the input argument.
          */
-        pStk->pzOutName = asprintf( pOutSpec->pzFileFmt,
-                                    pzDefFile, pOutSpec->zSuffix );
+        pStk->pzOutName = aprf( pOutSpec->pzFileFmt, pzDefFile,
+                                pOutSpec->zSuffix );
         if (p != NULL)
             *p = '.';
     }
@@ -331,6 +331,7 @@ openOutFile( tOutSpec* pOutSpec, tFpStack* pStk )
                 /*
                  *  Make the output a no-op, but perform the operations.
                  */
+                AGFREE( (void*)pStk->pzOutName );
                 pStk->pzOutName = (char*)zDevNull;
                 pStk->flags    |= FPF_STATIC_NM | FPF_NOUNLINK | FPF_NOCHMOD;
                 pStk->pFile     = fopen( zDevNull, "w" FOPEN_BINARY_FLAG );
@@ -347,8 +348,8 @@ openOutFile( tOutSpec* pOutSpec, tFpStack* pStk )
 
     if (pStk->pFile == NULL) {
     openError:
-        AG_ABEND( asprintf( zCannot, pzProg, errno, "create",
-                            pStk->pzOutName, strerror( errno )));
+        AG_ABEND( aprf( zCannot, pzProg, errno, "create",
+                        pStk->pzOutName, strerror( errno )));
     }
 }
 /*
