@@ -1,6 +1,6 @@
 
 /*
- *  $Id: autoopts.c,v 2.51 2002/10/12 18:07:51 bkorb Exp $
+ *  $Id: autoopts.c,v 2.54 2003/02/15 22:58:59 bkorb Exp $
  *
  *  This file contains all of the routines that must be linked into
  *  an executable to use the generated option processing.  The optional
@@ -9,7 +9,7 @@
  */
 
 /*
- *  Automated Options copyright 1992-2002 Bruce Korb
+ *  Automated Options copyright 1992-2003 Bruce Korb
  *
  *  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -65,8 +65,6 @@ tSCC zIllOptChr[]   = "%s: illegal option -- %c\n";
 tSCC zIllegal[]     = "illegal";
 tSCC zIllOptStr[]   = "%s: %s option -- %s\n";
 tSCC zAmbiguous[]   = "ambiguous";
-tSCC zOptArg[]      = "option argument";
-
 
 tSCC zOnlyOne[]     = "one %s%s option allowed\n";
 tSCC zAtMost[]      = "%4$d %1$s%s options allowed\n";
@@ -1000,13 +998,13 @@ loadOptionLine( pOpts, pOS, pzLine, direction )
     case ARG_MAY:
         if (*pOS->pzOptArg == NUL)
              pOS->pzOptArg = NULL;
-        else AGDUPSTR( pOS->pzOptArg, pOS->pzOptArg, zOptArg );
+        else AGDUPSTR( pOS->pzOptArg, pOS->pzOptArg, "option argument" );
         break;
 
     case ARG_MUST:
         if (*pOS->pzOptArg == NUL)
              pOS->pzOptArg = "";
-        else AGDUPSTR( pOS->pzOptArg, pOS->pzOptArg, zOptArg );
+        else AGDUPSTR( pOS->pzOptArg, pOS->pzOptArg, "option argument" );
         break;
     }
 
@@ -1238,7 +1236,7 @@ doEnvPresets( pOpts, type )
             case ARG_MUST:
                 if (*st.pzOptArg == NUL)
                      st.pzOptArg = "";
-                else AGDUPSTR( st.pzOptArg, st.pzOptArg, zOptArg );
+                else AGDUPSTR( st.pzOptArg, st.pzOptArg, "option argument" );
                 break;
 
             default: /* no argument allowed */
@@ -1531,7 +1529,8 @@ void optionLoadLine( pOpts, pzLine )
     tCC*       pzLine;
 {
     tOptState st = { NULL, OPTST_SET, TOPT_UNDEFINED, 0, NULL };
-    char* pz = AGDUPSTR( pzLine, pzLine, "user option line" );
+    char* pz;
+    AGDUPSTR( pz, pzLine, "user option line" );
     loadOptionLine( pOpts, &st, pz, DIRECTION_PROCESS );
     AGFREE( pz );
 }
