@@ -1,15 +1,15 @@
 
 /*
- *  Time-stamp:      "2002-09-21 10:54:11 bkorb"
+ *  Time-stamp:      "2003-01-05 11:20:13 bkorb"
  *
- *  autoopts.h  $Id: autoopts.h,v 2.27 2002/09/21 19:35:40 bkorb Exp $
+ *  autoopts.h  $Id: autoopts.h,v 2.33 2003/02/15 22:58:59 bkorb Exp $
  *
  *  This file defines all the global structures and special values
  *  used in the automated option processing library.
  */
 
 /*
- *  Automated Options copyright 1992-2002 Bruce Korb
+ *  Automated Options copyright 1992-2003 Bruce Korb
  *
  *  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -55,12 +55,11 @@
 #define AUTOGEN_AUTOOPTS_H
 
 #define __EXTENSIONS__
-#ifdef HAVE_CONFIG_H
-#  include "config.h"
-#  include "compat/compat.h"
-#endif
 
+#include "config.h"
+#include "compat/compat.h"
 #include <sys/param.h>
+
 #include "options.h"
 #include "streqv.h"
 
@@ -69,12 +68,6 @@
  */
 #define NUM_TO_VER(n)       ((n) >> 12), ((n) >> 7) & 0x001F, (n) & 0x007F
 
-/*
- *  Some systems have broken printf's!!
- *  So, always link with our own stdio library :-(
- */
-#include "snprintfv/snprintfv.h"
-
 #define NAMED_OPTS(po) \
         (((po)->fOptSet & (OPTPROC_SHORTOPT | OPTPROC_LONGOPT)) == 0)
 
@@ -159,6 +152,8 @@ typedef struct {
 #  define TAGMEM( m, t )
 
 #else  /* AUTOGEN_BUILD is defined: */
+#  include <snprintfv/printf.h>
+
 #  ifndef MEMDEBUG
      extern void* aopts_alloc( size_t, const char* );
      extern void* aopts_realloc( void*, size_t, const char* );
@@ -179,22 +174,26 @@ typedef struct {
          const char* pzWhence;
      };
 
-     extern void* aopts_alloc( size_t, const char*, const char* );
-     extern void* aopts_realloc( void*, size_t, const char*, const char* );
-     extern char* aopts_strdup( const char* pz, const char*, const char* );
+     extern void* aopts_alloc( size_t, const char* );
+     extern void* aopts_realloc( void*, size_t, const char* );
+     extern char* aopts_strdup( const char* pz, const char* );
      extern void  aopts_free( void* );
 
-#    define AO_HERE  __FILE__ " at " STR( __LINE__ )
-#    define AGALOC( c, w )      aopts_alloc( c, w, AO_HERE )
-#    define AGREALOC( p, c, w ) aopts_realloc( p, c, w, AO_HERE )
-#    define AGDUPSTR( p, s, w ) p = aopts_strdup( s, w, "strdup in " AO_HERE )
+#    define AO_HERE  " in " __FILE__ " at " STR( __LINE__ )
+#    define AGALOC( c, w )      aopts_alloc( c, w AO_HERE )
+#    define AGREALOC( p, c, w ) aopts_realloc( p, c, w AO_HERE )
+#    define AGDUPSTR( p, s, w ) p = aopts_strdup( s, w " - strdup" AO_HERE )
 #    define AGFREE( p )         aopts_free( p )
 #    define TAGMEM( m, t )      STMTS( tMemMgmt* p  = ((tMemMgmt*)m)-1; \
-                                tSCC z[] = t " in " AO_HERE; \
-                                p->pzWhence = z; )
+                                p->pzWhence = t " - TAGGED" AO_HERE; )
 #  endif /* MEMDEBUG */
 #endif /* AUTOGEN_BUILD */
 
+/*
+ *  File pointer for usage output
+ */
+extern FILE* option_usage_fp;
+
 /*
  *  optionUsage print the usage text for the program described by the
  *  option descriptor.  Does not return.  Calls ``exit(3)'' with exitCode.
